summaryrefslogtreecommitdiffstats
path: root/akregator/src/pluginmanager.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /akregator/src/pluginmanager.h
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'akregator/src/pluginmanager.h')
-rw-r--r--akregator/src/pluginmanager.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/akregator/src/pluginmanager.h b/akregator/src/pluginmanager.h
index 15d0c253e..ca97753f4 100644
--- a/akregator/src/pluginmanager.h
+++ b/akregator/src/pluginmanager.h
@@ -49,22 +49,22 @@ class PluginManager
* The keys used in the query (Type, ServiceType, Exec) are all
* fields found in the .desktop files.
*
* @param constraint A constraint to limit the choices returned, QString::null to
* get all services of the given @p servicetype
*
* @return A list of services that satisfy the query
* @see http://developer.kde.org/documentation/library/kdeqt/tradersyntax.html
*/
- static KTrader::OfferList query( const QString& constraint = QString::null );
+ static KTrader::OfferList query( const TQString& constraint = TQString::null );
/**
* Load and instantiate plugin from query
* @param constraint A constraint to limit the choices returned, QString::null to
* get all services of the given @p servicetype
* @return Pointer to Plugin, or NULL if error
* @see http://developer.kde.org/documentation/library/kdeqt/tradersyntax.html
*/
- static Akregator::Plugin* createFromQuery( const QString& constraint = QString::null );
+ static Akregator::Plugin* createFromQuery( const TQString& constraint = TQString::null );
/**
* Load and instantiate plugin from service
@@ -96,7 +96,7 @@ class PluginManager
* Show modal info dialog about plugin
* @param constraint A constraint to limit the choices returned
*/
- static void showAbout( const QString& constraint );
+ static void showAbout( const TQString& constraint );
private:
struct StoreItem {
@@ -49,22 +49,22 @@ class PluginManager
* fields found in the .desktop files.
*
- * @param constraint A constraint to limit the choices returned, QString::null to
+ * @param constraint A constraint to limit the choices returned, TQString::null to
* get all services of the given @p servicetype
*
@@ -49,22 +49,22 @@ class PluginManager
/**
* Load and instantiate plugin from query
- * @param constraint A constraint to limit the choices returned, QString::null to
+ * @param constraint A constraint to limit the choices returned, TQString::null to
* get all services of the given @p servicetype
* @return Pointer to Plugin, or NULL if error